@@ -6,7 +6,7 @@
 !  Largo Pontecorvo 5                                         !
 !  56127 Pisa                                                 !
 !  Italy                                                      !
-!  Version 1.1 - Oct 2006                                     !
+!  Version 1.2 - Nov 2006                                     !
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 !   fcalls.f90   main calls from C to  Fortran computation    !
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
@@ -49,14 +49,10 @@ integer goalflag  ! input:   1= G only, 2= G and R, 3= G, R and U,  4= G, R, U a
 integer errorflag ! output:  0= no error else some error did force premature termination
 integer itermax   ! input:   max number of allowed iterations, default=50
 integer errmax    ! input:   eps = epsilon(1.0d0)* 10 ** errmax
-integer regend    ! output   0= regular end of computation 1= did non finish 
 logical ::  ds, dg  ! algorithm flags
-real(dpr)::drift  , myeps   !
-integer m, stat     ! for allocating matrices
+real(dpr)::drift 
+integer m         ! for allocating matrices
 ! integer :: maxnc  ! max number of block components of Pi
-integer :: m0     ! size of the block B0
-! maxnc=20;
-! myeps=1.d-40
 !
 !
 !
@@ -93,7 +89,6 @@ case default
 end select
 
 m=size(A,1) 
-m0=m !!!!Pas
 
 select case(goalflag)
 case (1) ! G only
@@ -268,10 +263,9 @@ integer goalflag  ! input:   1= G only, 2= G and R, 3= G, R and U,  4= G, R, U a
 integer errorflag ! output:  0= no error else some error did force premature termination
 integer itermax   ! input:   max number of allowed iterations, default=50
 integer errmax    ! input:   eps = epsilon(1.0d0)* 10 ** errmax
-integer regend    ! output   0= regular end of computation 1= did non finish 
 logical ::  ds, dg  ! algorithm flags
-real(dp)::drift     !
-integer m, stat     ! for allocating matrices
+real(dp)::drift    
+integer m         
 !
 !
 if (debug) write (*,*) "qbd_lr_solve: entering with algflag=",algflag,&
@@ -444,9 +438,8 @@ integer goalflag  ! input:   1= G only, 2= G and R, 3= G, R and U,  4= G, R, U a
 integer errorflag ! output:  0= no error else some error did force premature termination
 integer itermax   ! input:   max number of allowed iterations, default=50
 integer errmax    ! input:   eps = epsilon(1.0d0)* 10 ** errmax
-integer regend    ! output   0= regular end of computation 1= did non finish 
 real(dp)::drift,norm1,myeps     !
-integer m, stat     ! for allocating matrices
+integer m
 logical ::  ds    ! do shift
 integer :: method ! 1 natural, 2 traditional, 3 U-based (default)
 integer :: i
@@ -699,9 +692,8 @@ integer goalflag  ! input:   1= G only, 2= G and R, 3= G, R and U,  4= G, R, U a
 integer errorflag ! output:  0= no error else some error did force premature termination
 integer itermax   ! input:   max number of allowed iterations, default=50
 integer errmax    ! input:   eps = epsilon(1.0d0)* 10 ** errmax
-integer regend    ! output   0= regular end of computation 1= did non finish 
 real(dp)::drift,norm1,myeps     !
-integer m, stat     ! for allocating matrices
+integer m  
 !
 !
 !
@@ -833,14 +825,11 @@ integer errorflag ! output:  0= no error else some error did force premature ter
 integer itermax   ! input:   max number of allowed iterations, default=50
 integer errmax    ! input:   eps = epsilon(1.0d0)* 10 ** errmax
 integer interpmax ! input:   man number of allowed interpolations, default=1  #interpolations= 256*2**interpmax
-integer regend    ! output   0= regular end of computation 1= did non finish 
-real(dp)::drift,norm1,myeps     !
-integer m, stat     ! for allocating matrices
+real(dp)::norm1,myeps     
+integer m
 !
 !
 !
-integer na,maxnc,m0
-
 
 if (debug) write (*,*) "mg1_cr_solve: entering with algflag=",algflag,&
     " goalflag=",goalflag," errorflag=",errorflag," eps=",errmax," niter=",&
@@ -989,9 +978,8 @@ integer goalflag  ! input:   1= G only, 2= G  and Pi
 integer errorflag ! output:  0= no error else some error did force premature termination
 integer itermax   ! input:   max number of allowed iterations, default=50
 integer errmax    ! input:   eps = epsilon(1.0d0)* 10 ** errmax
-integer regend    ! output   0= regular end of computation 1= did non finish 
 real(dp)::drift,norm1,myeps     !
-integer m, stat     ! for allocating matrices
+integer m
 logical ::  ds    ! do shift
 integer :: method ! 1 natural, 2 traditional, 3 U-based (default)
 integer :: i
@@ -1201,10 +1189,8 @@ integer goalflag  ! input:   1= G only, 2= G and Pi
 integer errorflag ! output:  0= no error else some error did force premature termination
 integer itermax   ! input:   max number of allowed iterations, default=50
 integer errmax    ! input:   eps = epsilon(1.0d0)* 10 ** errmax
-integer regend    ! output   0= regular end of computation 1= did non finish 
 real(dp)::drift,norm1,myeps     !
-integer m, stat     ! for allocating matrices
-integer :: method 
+integer m
 !
 !
 !
@@ -1284,10 +1270,9 @@ integer errorflag ! output:  0= no error else some error did force premature ter
 integer itermax   ! input:   max number of allowed iterations, default=50
 integer interpmax ! input:   man number of allowed interpolations, default=1  #interpolations= 256*2**interpmax
 integer errmax    ! input:   eps = epsilon(1.0d0)* 10 ** errmax
-integer regend    ! output   0= regular end of computation 1= did non finish 
-real(dp)::drift,norm1,myeps     !
-integer m, stat     ! for allocating matrices
-integer:: nba,  i,maxnc,nbb
+real(dp)::norm1,myeps     
+integer m
+integer:: nba,  i
  real(dp),dimension(:),allocatable :: vi,v 
 ! real(dp),dimension(:,:),allocatable :: B0,bm1
  real(dp),dimension(:,:,:),allocatable :: AA
@@ -1512,9 +1497,6 @@ integer goalflag  ! input:   1= R only, 2=  R and Pi
 integer errorflag ! output:  0= no error else some error did force premature termination
 integer itermax   ! input:   max number of allowed iterations, default=50
 integer errmax    ! input:   eps = epsilon(1.0d0)* 10 ** errmax
-integer regend    ! output   0= regular end of computation 1= did non finish 
-real(dp)::drift,norm1,myeps     !
-integer m, stat     ! for allocating matrices
 !
 !
 !
@@ -1523,7 +1505,6 @@ if (debug) write (*,*) "gim1_lr_solve: entering with algflag=",algflag,&
 !
 finish=.false.
 info =0; fdrift=0
-myeps=epsilon(1.d0) * 10.0d0 ** errmax
 !
 !
 ! disallocate G,R,U,Pi,Pi0 if allocated
@@ -1534,8 +1515,6 @@ if (allocated(U)) deallocate(U)
 if (allocated(Pi)) deallocate(Pi)
 if (allocated(Pi0)) deallocate(Pi0)
 
-m=size(A,1)
-!!
 write(wout,*)"********** algorithm not ready ********** work in progress **********"
 call print_it
 !!
@@ -1580,9 +1559,8 @@ integer goalflag  ! input:   1= R only, 2= R and Pi
 integer errorflag ! output:  0= no error else some error did force premature termination
 integer itermax   ! input:   max number of allowed iterations, default=50
 integer errmax    ! input:   eps = epsilon(1.0d0)* 10 ** errmax
-integer regend    ! output   0= regular end of computation 1= did non finish 
 real(dp)::drift,norm1,myeps     !
-integer m, stat     ! for allocating matrices
+integer m
 logical ::  ds    ! do shift
 integer :: method ! 1 natural, 2 traditional, 3 U-based (default)
 integer :: i,nba
@@ -1841,10 +1819,9 @@ integer goalflag  ! input:   1= R only, 2= R and Pi
 integer errorflag ! output:  0= no error else some error did force premature termination
 integer itermax   ! input:   max number of allowed iterations, default=50
 integer errmax    ! input:   eps = epsilon(1.0d0)* 10 ** errmax
-integer regend    ! output   0= regular end of computation 1= did non finish 
 real(dpr)::drift,norm1,myeps     !
-integer m, stat     ! for allocating matrices
-integer :: nba, method,i
+integer m
+integer :: nba, i
 real(dpr),dimension(:,:,:),allocatable:: AA
 real(dpr),dimension(:),allocatable:: v,vi
 !
@@ -1961,15 +1938,12 @@ integer errorflag ! output:  0= no error else some error did force premature ter
 integer :: maxnc, pinc  ! max and computed number of block components of Pi
 integer :: boptflag ! 1 if b is present  0 if not present
 integer :: epspi    ! input:   myeps = epsilon(1.0d0)* 10 ** epspi
-integer regend    ! output   0= regular end of computation 1= did non finish
-logical ::  ds, dg  ! algorithm flags
-real(dp)::drift  , myeps   !
-integer m,n, stat     ! for allocating matrices
+real(dp):: myeps  
+integer m,n
 !integer :: m0     ! size of the block B0
 !
 finish=.false.
 info =0
-regend=1
 myeps=epsilon(1.d0) * 10.0d0 ** epspi
 errorflag=info
 !
@@ -2006,7 +1980,6 @@ call qbdpi(am1=A(:,:,1),a0=A(:,:,2),a1=A(:,:,3),bm1=BN1,  b0=B0,  R=R,&
 end if
 if (verb) write (wout,*) " Number of computed blocks of components of pi= ",pinc
 call print_it
-regend=0
 end subroutine qbd_pi_ponte
 
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
@@ -2040,15 +2013,12 @@ integer errorflag ! output:  0= no error else some error did force premature ter
 integer :: maxnc, pinc  ! max and computed number of block components of Pi
 integer :: epspi    ! input:   myeps = epsilon(1.0d0)* 10 ** epspi
 integer :: bn1flag ! 1 if bn1 is present  0 if not present 
-integer regend    ! output   0= regular end of computation 1= did non finish
-logical ::  ds, dg  ! algorithm flags
-real(dp)::drift  , myeps   !
-integer m,n, stat     ! for allocating matrices
+real(dp):: myeps   
+integer m,n
 !integer :: m0     ! size of the block B0
 !
 finish=.false.
 info =0
-regend=1
 myeps=epsilon(1.d0) * 10.0d0 ** epspi
 errorflag=info
 !
@@ -2086,7 +2056,6 @@ else
 call mg1pi(A=A, B0=B0, B=B,  G=G, maxnc=maxnc, epspi=myeps, pi0=pi0, pi=pi, pinc=pinc)
 end if
 if (verb)  write (wout,*) " Number of computed blocks of components of pi= ",pinc
-regend=0
 end subroutine mg1_pi_ponte
 
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
@@ -2120,15 +2089,12 @@ integer errorflag ! output:  0= no error else some error did force premature ter
 integer :: maxnc, pinc  ! max and computed number of block components of Pi
 integer :: epspi    ! input:   myeps = epsilon(1.0d0)* 10 ** epspi
 integer :: bn1flag ! 1 if bn1 is present  0 if not present 
-integer regend    ! output   0= regular end of computation 1= did non finish
-logical ::  ds, dg  ! algorithm flags
-real(dp)::drift  , myeps   !
-integer m,n, stat     ! for allocating matrices
+real(dp):: myeps  
+integer m,n
 !integer :: m0     ! size of the block B0
 !
 finish=.false.
 info =0
-regend=1
 myeps=epsilon(1.d0) * 10.0d0 ** epspi
 errorflag=info
 !
@@ -2165,5 +2131,4 @@ else
 call gm1pi(A=A, B=B, B0=B0,  R=R, maxnc=maxnc, epspi=myeps, pi0=pi0, pi=pi, pinc=pinc)
 end if
 if (verb)  write (wout,*) " Number of computed blocks of components of pi= ",pinc
-regend=0
 end subroutine gim1_pi_ponte
