@@ -6,7 +6,7 @@
  * Largo Pontecorvo 5                                         *
  * 56127 Pisa                                                 *
  * Italy                                                      *
- * Version 1.1 - Oct 2006                                     *
+ * Version 1.2 - Nov 2006                                     *
  **************************************************************
  *
  *  help.c  - about and  help window interfaces and callbacks
@@ -45,7 +45,7 @@ create_window_about (void)
   gtk_frame_set_shadow_type (GTK_FRAME(frame),GTK_SHADOW_ETCHED_IN);
   gtk_widget_show(frame);
   gtk_container_add(GTK_CONTAINER(dialog_vbox),frame); 
-  label = gtk_label_new("\n\nStructured Markov Chains Solver\n\nDario Bini, Beatrice Meini, Sergio Steffe\'\n\nDipartimento di Matematica \"Leonida Tonelli\"\nUniversita\' di Pisa, Pisa, Italy\n {bini, meini, steffe}@dm.unipi.it\n\nVersion 1.1 Oct 2006\n\n");
+  label = gtk_label_new("\n\nStructured Markov Chains Solver\n\nDario Bini, Beatrice Meini, Sergio Steffe\'\n\nDipartimento di Matematica \"Leonida Tonelli\"\nUniversita\' di Pisa, Pisa, Italy\n {bini, meini, steffe}@dm.unipi.it\n\nVersion 1.2 Nov 2006\n\n");
   gtk_widget_show(label);
   gtk_container_add(GTK_CONTAINER(frame),label);
   
@@ -59,7 +59,7 @@ create_window_about (void)
   gtk_widget_show(about_me);
 
   g_signal_connect ((gpointer) closebutton, "clicked", G_CALLBACK (on_about_closebutton_clicked), NULL);
-  g_signal_connect ((gpointer) about_me, "delete_event", G_CALLBACK (on_about_closebutton_clicked),NULL); 
+  g_signal_connect ((gpointer) about_me, "destroy", G_CALLBACK (on_about_destroy_activate),NULL); 
 }
 /*********************************/
 
@@ -181,7 +181,7 @@ create_window_help (void)
   GTK_WIDGET_SET_FLAGS (closebutton, GTK_CAN_DEFAULT);
 
   g_signal_connect ((gpointer) closebutton, "clicked", G_CALLBACK (on_help_closebutton_clicked), NULL);
-  g_signal_connect ((gpointer) help_window, "delete_event", G_CALLBACK (on_help_closebutton_clicked),NULL);
+  g_signal_connect ((gpointer) help_window, "destroy", G_CALLBACK (on_help_destroy_activate),NULL);
   g_signal_connect ((gpointer) title1, "clicked", G_CALLBACK (on_help_title1_clicked), NULL); 
   g_signal_connect ((gpointer) title2, "clicked", G_CALLBACK (on_help_title2_clicked), NULL); 
   g_signal_connect ((gpointer) title2, "clicked", G_CALLBACK (on_help_title2_clicked), NULL); 
