@@ -6,7 +6,7 @@
  * Largo Pontecorvo 5                                         *
  * 56127 Pisa                                                 *
  * Italy                                                      *
- * Version 1.1 - Oct 2006                                     *
+ * Version 1.2 - Nov 2006                                     *
  **************************************************************
  *
  *  view_pi.c - view Pi quich hack  - both callbacks and interfaces
@@ -58,7 +58,7 @@ int is_nan; /* 1=not a number discovered 0=0k */
 is_nan=0;
 data=calloc(1,sizeof(struct viewpi_str));
 if(data==NULL) {create_dialog_nogo2( window_main); return;};
-if(is_debug==1) printf("create_view_pi_window: data structure allocated\n");
+if(is_debug==1) printf("create_view_pi_window: data structure allocated data=%ld\n",(long int)data);
 /* window view pi */
 data->window_view_pi=gtk_window_new (GTK_WINDOW_TOPLEVEL);
 if (data->window_view_pi==NULL) {create_dialog_nogo2( window_main); return;};
@@ -212,6 +212,7 @@ if(is_debug==1) printf("create_view_pi_window: beginning plot allocations\n");
 /* allocate the drawing buffer */
 data->rgb_view_pivalue=calloc(3*(HPL)*VPL,sizeof(guchar));
 if(data->rgb_view_pivalue==NULL) {create_dialog_nogo2( window_main); return;};
+if(is_debug==1)printf("create_view_pi_window: allocated data->rgb_view_pivalue=%ld\n",(long int)data->rgb_view_pivalue);
 /* allocate pi data vector */
 data->pi_num =completed.dimension_n+completed.maxnc*completed.dimension_m;
 pi_data=calloc(data->pi_num,sizeof(double));
@@ -258,10 +259,9 @@ if ((pi_min <-1.0E-12)||(pi_max > 1)||(is_nan==1)) {create_dialog_nogo1( window_
 free(pi_data);
 pi_image_compute(data);
 
-
-g_signal_connect ((gpointer) data->window_view_pi, "delete_event", G_CALLBACK (on_view_pi_delete_activate),(gpointer)data);
-g_signal_connect ((gpointer) data->window_view_pi, "destroy_event", G_CALLBACK (on_view_pi_delete_activate),(gpointer)data);
-
+/* g_signal_connect ((gpointer) data->window_view_pi, "window_state_event", G_CALLBACK (on_view_pi_state_print),(gpointer)data); */
+/* g_signal_connect ((gpointer) data->window_view_pi, "delete_event", G_CALLBACK (on_view_pi_delete_activate),(gpointer)data); */
+g_signal_connect ((gpointer) data->window_view_pi, "destroy", G_CALLBACK (on_view_pi_destroy_activate),(gpointer)data);
 g_signal_connect ((gpointer) button_quit_view_pi, "clicked", G_CALLBACK(on_view_pi_menu_quit_activate),(gpointer)data);
 g_signal_connect ((gpointer) button_rescale_view_pi, "clicked", G_CALLBACK(on_view_pi_menu_rescale_activate),(gpointer)data);
 g_signal_connect ((gpointer) button_log_view_pi, "clicked", G_CALLBACK(on_view_pi_menu_log_activate),(gpointer)data);
@@ -276,29 +276,64 @@ gtk_widget_show(data->window_view_pi);
 void
 on_view_pi_menu_quit_activate   (GtkMenuItem  *menuitem, gpointer  data)
 {
-if(is_debug==1) printf("on_view_pi_menu_quit_activate: quit\n");
+if(is_debug==1) printf("on_view_pi_menu_quit_activate: quit data=%ld\n",(long int)data);
 gtk_widget_destroy(GTK_WIDGET(((struct viewpi_str *)data)->window_view_pi));
-/* free space of the graphic buffers */
-free(((struct viewpi_str *)data)->rgb_view_pivalue); 
-free(((struct viewpi_str *)data)->pi_s_data);
+/* this will generate a destroy event */
 if(is_debug==1) printf("on_view_pi_menu_quit_activate: exiting \n");
 }
 /*********************************/
 
-/* View  Pi Window: delete  **** Callback */
+/* View  Pi Window: destroy  **** Callback */
 void
-on_view_pi_delete_activate   (GtkWidget  *ww, gpointer data)
+on_view_pi_destroy_activate   (GtkWidget  *ww, gpointer data)
 {
 /* www is the calling window */
-if(is_debug==1) printf("on_view_pi_delete_activate: quit\n");
+if(is_debug==1) printf("on_view_pi_destroy_activate: quit data=%ld\n",(long int)data);
 gtk_widget_destroy(GTK_WIDGET(ww));
-/* free space of the graphic buffers */
+/* free space of the graphic buffers and structure data itself */
 free(((struct viewpi_str *)data)->rgb_view_pivalue);
 free(((struct viewpi_str *)data)->pi_s_data);
-if(is_debug==1) printf("on_view_pi_delete_activate: exiting \n");
+free((struct viewpi_str *)data);
+if(is_debug==1) printf("on_view_pi_destroy_activate: exiting \n");
 }
 /*********************************/
 
+/* View  Pi Window: delete_event  **** Callback ** for debug only */
+gboolean
+on_view_pi_delete_activate   (GtkWidget  *ww, GdkEvent *event, gpointer data)
+{
+/* www is the calling window */
+if(is_debug==1) printf("on_view_pi_delete_activate: quit data=%ld\n",(long int)data);
+if(is_debug==1) printf("on_view_pi_delete_activate: exiting \n");
+return(FALSE);
+}
+/*********************************/
+
+/* print state of the window  - not used - made some tests */
+gboolean 
+on_view_pi_state_print (GtkWidget  *ww, GdkEvent  *event ,gpointer data)
+{
+
+if(is_debug==1) printf("on_view_pi_state_print: data=%ld event=%ld type=%d \n",(long int)data,(long int)event,event->type);
+/* GDK_WINDOW_STATE =32 */
+if((is_debug==1)&&(event->type==GDK_WINDOW_STATE)) { /* print the window state */
+	printf("on_view_pi_state_print: GDK_WINDOW_STATE =%d \n",(event->window_state.changed_mask));	
+
+	}
+/*
+if (event->window_state.send_event==FALSE) {
+		gtk_window_iconify (GTK_WINDOW(ww)); 
+		return(FALSE);
+	} else  {
+		gtk_window_deiconify (GTK_WINDOW(ww));
+		return(TRUE);
+		}
+*/
+return(TRUE);
+}
+/*********************************/
+
+
 
 /* View  Pi Window: Rescale  **** Callback */
 void
